
bservices
=========

A server service library Based on **oslo.service**.

* **WSGI Server:** Handle the WSGI request.
    See https://github.com/xgfone/bservices/blob/master/bservices/examples/wsgi_server_example.py
* **TCP  Server:** Handle the TCP request.
    See https://github.com/xgfone/bservices/blob/master/bservices/examples/tcp_server_example.py
* **Pool Server:** Handle the you-defined request.
    See https://github.com/xgfone/bservices/blob/master/bservices/examples/pool_server_example.py
* **Task Server:** Handle the task.
    See https://github.com/xgfone/bservices/blob/master/bservices/examples/task_server_example.py
